@@ -7,22 +7,25 @@ from androguard.core.bytecodes.apk import APK
 
 @click.command()
 @click.option('--run', is_flag=True)
+@click.option('--run_only', is_flag=True)
 @click.option('--default', is_flag=True)
 @click.option('--ks_pass', default='pyapksigner123!')
 @click.option('--key_pass', default='pyapksigner123!')
 @click.option('--key_alias', default='pyapksigner')
 @click.option('--key_path', default='pyapksigner.jks')
 @click.argument('apk')
-def cli(apk: str, default: bool, key_path: str, key_alias: str, key_pass: str, ks_pass: str, run: bool):
-    if key_path == 'pyapksigner.jks':
-        if not default:
-            print("[Warning] Signing with default keystore.")
-            print("[Warning] Please pass --key_path, --key_alias, --key_pass, --ks_pass parameter, if you want to use your keystore")
-        key_path = str(config.ROOT_DIR.joinpath(key_path).resolve())
+def cli(apk: str, default: bool, key_path: str, key_alias: str, key_pass: str, ks_pass: str, run: bool, run_only: bool):
+    apk_path = apk
+    if not run_only:
+        if key_path == 'pyapksigner.jks':
+            if not default:
+                print("[Warning] Signing with default keystore.")
+                print("[Warning] Please pass --key_path, --key_alias, --key_pass, --ks_pass parameter, if you want to use your keystore")
+            key_path = str(config.ROOT_DIR.joinpath(key_path).resolve())
 
-    apk_path = launcher(apk, key_path, key_alias, key_pass, ks_pass)
+        apk_path = launcher(apk, key_path, key_alias, key_pass, ks_pass)
 
-    if run:
+    if run or run_only:
        apk = APK(apk_path) 
 
        def adb(cmd):
